django\_opt\_out\.migrations package
====================================

Submodules
----------

django\_opt\_out\.migrations\.0001\_initial module
--------------------------------------------------

.. automodule:: django_opt_out.migrations.0001_initial
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_opt_out.migrations
    :members:
    :undoc-members:
    :show-inheritance:
